@@ -1,5 +1,6 @@
 import argparse
 import os
+from posixpath import dirname
 
 from bbb_dlc.version import __version__
 from bbb_dlc.bigbluebutton_api_python import BigBlueButton
@@ -39,9 +40,20 @@ class BBBDLC:
             passthroughArgs += recordingUrl
             os.chdir(ncPath + "/admin/files")
             os.system("bbb-dl " + passthroughArgs)
+            os.system("mv " + args.recordId + "/slideshow.mp4 " + args.recordId + "v.mp4")
+            os.system("rm -r " + args.recordId)
+
+            os.chdir(get_parent(args.ncCfg, 2))
+            os.system("/opt/plesk/php/7.3/bin/php ./occ files:scan admin")
         except Exception as e:
-            print(e)
+            #print(e)
+            errorLog = open("/var/www/vhosts/sapienslab.com.mx/logs/bbb_error_log", "a")
+            errorLog.write(e)
+            errorLog.close()
         
+def get_parent(dirName, dirUp):
+    for i in range(dirUp):
+        dirName = os.path.dirname(dirname)
 
 def get_parser():
     """
@@ -107,6 +119,7 @@ def get_parser():
         default='libx264',
         help='Optional encoder to pass to ffmpeg (default libx264)',
     )
+
     parser.add_argument(
         '--audiocodec',
         dest='audiocodec',
